@@ -1,20 +1,26 @@
 """Provide a CLI for Tradfri."""
-import logging
-from pprint import pprint
-
-from .const import *  # noqa
-from pytradfri.api.libcoap_api import APIFactory
-from pytradfri.util import load_json, save_json
-from pytradfri.error import PytradfriError
-from .gateway import Gateway
-from .command import Command
+from __future__ import annotations
 
 import argparse
+import logging
+from pprint import pprint
 import uuid
 
-if __name__ == "__main__":
-    CONFIG_FILE = "tradfri_standalone_psk.conf"
+from pytradfri.api.libcoap_api import APIFactory
+from pytradfri.device import Device
+from pytradfri.error import PytradfriError
+from pytradfri.group import Group
+from pytradfri.util import load_json, save_json
 
+from .command import Command
+from .gateway import Gateway
+
+CONFIG_FILE = "tradfri_standalone_psk.conf"
+
+# pylint: disable=invalid-name
+
+
+if __name__ == "__main__":
     logging.basicConfig(level=logging.DEBUG)
 
     parser = argparse.ArgumentParser()
@@ -28,9 +34,9 @@ if __name__ == "__main__":
         required=False,
         help="Security code found on your Tradfri gateway",
     )
-    args = parser.parse_args()
+    org_args = parser.parse_args()
 
-    if args.host not in load_json(CONFIG_FILE) and args.key is None:
+    if org_args.host not in load_json(CONFIG_FILE) and org_args.key is None:
         print(
             "Please provide the 'Security Code' on the back of your "
             "Tradfri gateway:",
@@ -41,31 +47,30 @@ if __name__ == "__main__":
             raise PytradfriError(
                 "'Security Code' has to be exactly" + "16 characters long."
             )
-        else:
-            args.key = key
+        org_args.key = key
 
     conf = load_json(CONFIG_FILE)
 
     try:
-        identity = conf[args.host].get("identity")
-        psk = conf[args.host].get("key")
-        api_factory = APIFactory(host=args.host, psk_id=identity, psk=psk)
+        identity = conf[org_args.host].get("identity")
+        psk = conf[org_args.host].get("key")
+        api_factory = APIFactory(host=org_args.host, psk_id=identity, psk=psk)
     except KeyError:
         identity = uuid.uuid4().hex
-        api_factory = APIFactory(host=args.host, psk_id=identity)
+        api_factory = APIFactory(host=org_args.host, psk_id=identity)
 
         try:
-            psk = api_factory.generate_psk(args.key)
+            psk = api_factory.generate_psk(org_args.key)
             print("Generated PSK: ", psk)
 
-            conf[args.host] = {"identity": identity, "key": psk}
+            conf[org_args.host] = {"identity": identity, "key": psk}
             save_json(CONFIG_FILE, conf)
-        except AttributeError:
+        except AttributeError as exc:
             raise PytradfriError(
                 "Please provide the 'Security Code' on the "
                 "back of your Tradfri gateway using the "
                 "-K flag."
-            )
+            ) from exc
 
     api = api_factory.request
 
@@ -74,7 +79,7 @@ if __name__ == "__main__":
     devices = api(devices_commands)
     lights = [dev for dev in devices if dev.has_light_control]
     if lights:
-        light = lights[0]
+        light: Device | None = lights[0]
     else:
         print("No lights found!")
         light = None
@@ -82,7 +87,7 @@ if __name__ == "__main__":
     groups = api(groups_commands)
     moods = []
     if groups:
-        group = groups[0]
+        group: Group | None = groups[0]
         for group in groups:
             moods_commands = api(group.moods())
             group_moods = api(moods_commands)
@@ -94,7 +99,8 @@ if __name__ == "__main__":
     tasks = api(tasks_commands)
     homekit_id = api(gateway.get_gateway_info()).homekit_id
 
-    def dump_all():
+    def dump_all() -> None:
+        """Dump all endpoints."""
         endpoints = api(gateway.get_endpoints())
 
         for endpoint in endpoints:
@@ -107,7 +113,8 @@ if __name__ == "__main__":
             print()
             print()
 
-    def dump_devices():
+    def dump_devices() -> None:
+        """Dump devices."""
         pprint([d.raw for d in devices])
 
     print()
